@@ -1,13 +1,16 @@
 import pickle
 import sys
 
-import six
-from twisted.python.failure import Failure
+import pytest
 
 from tblib import pickling_support
 
+pytest.importorskip('twisted')
+
 
 def test_30():
+    from twisted.python.failure import Failure
+
     pickling_support.install()
 
     try:
@@ -17,7 +20,8 @@ def test_30():
 
     f = None
     try:
-        six.reraise(*pickle.loads(s))
+        etype, evalue, etb = pickle.loads(s)
+        raise evalue.with_traceback(etb)
     except ValueError:
         f = Failure()
 
